==> qtjambi-webenginecore-6.2.7-sources.jar: io/qt/webengine/core/QWebEngineFullScreenRequest.java <==
package io.qt.webengine.core;


/**
 * <p>Enables accepting or rejecting requests for entering and exiting the fullscreen mode</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qwebenginefullscreenrequest.html">QWebEngineFullScreenRequest</a></p>
 */
public class QWebEngineFullScreenRequest extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QWebEngineFullScreenRequest.class);
    
    
    public QWebEngineFullScreenRequest(io.qt.webengine.core.QWebEngineFullScreenRequest other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QWebEngineFullScreenRequest instance, io.qt.webengine.core.QWebEngineFullScreenRequest other);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginefullscreenrequest.html#accept">QWebEngineFullScreenRequest::accept()</a></p>
     */
    public final void accept(){
        accept_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void accept_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void set(io.qt.webengine.core.QWebEngineFullScreenRequest other){
        set_native_cref_QWebEngineFullScreenRequest(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native void set_native_cref_QWebEngineFullScreenRequest(long __this__nativeId, long other);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginefullscreenrequest.html#origin">QWebEngineFullScreenRequest::origin()const</a></p>
     */
    @io.qt.QtPropertyReader(name="origin")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.core.QUrl origin(){
        return origin_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QUrl origin_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginefullscreenrequest.html#reject">QWebEngineFullScreenRequest::reject()</a></p>
     */
    public final void reject(){
        reject_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void reject_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginefullscreenrequest.html#toggleOn">QWebEngineFullScreenRequest::toggleOn()const</a></p>
     */
    @io.qt.QtPropertyReader(name="toggleOn")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final boolean toggleOn(){
        return toggleOn_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean toggleOn_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QWebEngineFullScreenRequest(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QWebEngineFullScreenRequest clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QWebEngineFullScreenRequest clone_native(long __this_nativeId);
}

==> qtjambi-webenginecore-6.4.1-sources.jar: io/qt/webengine/core/QWebEngineFullScreenRequest.java <==
package io.qt.webengine.core;


/**
 * <p>Enables accepting or rejecting requests for entering and exiting the fullscreen mode</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qwebenginefullscreenrequest.html">QWebEngineFullScreenRequest</a></p>
 */
public class QWebEngineFullScreenRequest extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QWebEngineFullScreenRequest.class);
    
    
    public QWebEngineFullScreenRequest(io.qt.webengine.core.QWebEngineFullScreenRequest other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QWebEngineFullScreenRequest instance, io.qt.webengine.core.QWebEngineFullScreenRequest other);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginefullscreenrequest.html#accept">QWebEngineFullScreenRequest::accept()</a></p>
     */
    public final void accept(){
        accept_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void accept_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void set(io.qt.webengine.core.QWebEngineFullScreenRequest other){
        set_native_cref_QWebEngineFullScreenRequest(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native void set_native_cref_QWebEngineFullScreenRequest(long __this__nativeId, long other);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginefullscreenrequest.html#origin">QWebEngineFullScreenRequest::origin()const</a></p>
     */
    @io.qt.QtPropertyReader(name="origin")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.core.QUrl origin(){
        return origin_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QUrl origin_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginefullscreenrequest.html#reject">QWebEngineFullScreenRequest::reject()</a></p>
     */
    public final void reject(){
        reject_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void reject_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginefullscreenrequest.html#toggleOn">QWebEngineFullScreenRequest::toggleOn()const</a></p>
     */
    @io.qt.QtPropertyReader(name="toggleOn")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final boolean toggleOn(){
        return toggleOn_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean toggleOn_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QWebEngineFullScreenRequest(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QWebEngineFullScreenRequest clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QWebEngineFullScreenRequest clone_native(long __this_nativeId);
}
